<?php

namespace Constantine\Ship\Http\Controllers;

use App\Models\Country;
use Dcat\Admin\Form;
use Dcat\Admin\Grid;
use Dcat\Admin\Show;
use Dcat\Admin\Http\Controllers\AdminController;
use Constantine\Ship\Models\ShipDate;

class ShipController extends AdminController
{
    protected function grid()
    {
        return Grid::make(new ShipDate(), function (Grid $grid) {
            $grid->showColumnSelector();
            $grid->quickSearch(['country_code']);
            $grid->column('id')->sortable();
            $grid->column('country_code');
            $grid->column('ship_text')->editable();
            $grid->column('traffic_text')->editable();
            $grid->column('button_text')->editable();
            $grid->column('extra')->hide();
            $grid->column('ship', 'ship')->help('发货内容');
            $grid->column('status')->switch();
            $grid->column('ship_status')->switch()->help('是否显示发货信息');
            $grid->column('cart_text', '购物车内容');
            $grid->column('created_at');
            $grid->column('updated_at')->sortable();
            $grid->tools(function (Grid\Tools $tools){
                $tools->disableRefreshButton();
                $tools->disableFilterButton();
            });
            $grid->filter(function (Grid\Filter $filter) {
                $filter->equal('id');
            });
        });
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     *
     * @return Show
     */
    protected function detail($id)
    {
        return Show::make($id, new ShipDate(), function (Show $show) {
            $show->field('id');
            $show->field('lang');
            $show->field('ship_text');
            $show->field('traffic_text');
            $show->field('extra');
            $show->field('created_at');
            $show->field('updated_at');
        });
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        return Form::make(new ShipDate(), function (Form $form) {
            $form->display('id');
            $countries = Country::query()->where('status', 1)->get();
            $countryOptions = [];
            foreach ($countries as $country) {
                $translate = json_decode($country->translations, true);
                $countryOptions[$country->iso2] = $country->name . '|' . $translate['cn'];
            }
            $form->select('country_code')->options($countryOptions)->required();
            $form->textarea('ship_text')->required()->help('ship_text');
            $form->textarea('traffic_text')->required()->help('traffic_text');
            $form->editor('extra', '内容')->help('extra');
            $form->textarea('ship', '发货内容')->help('ship');
            $form->text('button_text', '标题')->help('button_text');
            $form->editor('cart_text', '购物车页面内容');
            $form->switch('status', '是否启用')->customFormat(function ($v) {
                return $v;
            })
                ->saving(function ($v) {
                    return $v;
                });
            $form->switch('ship_status', '是否启用运费')->customFormat(function ($v) {
                return $v;
            })
                ->saving(function ($v) {
                    return $v;
                });
            $form->display('created_at');
            $form->display('updated_at');
        });
    }
}
